==> nextcloud-29.0.5.tgz: nextcloud/apps/logreader/l10n/cs.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Záznam událostí",
    "Errors in the log" : "Chyby v záznamu událostí",
    "No errors in the logs since %s" : "Žádné chyby v záznamech událostí od %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%nchyba v záznamech událostí od %s","%nchyby v záznamech událostí od %s","%nchyby v záznamech událostí od %s","%nchyby v záznamech událostí od %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n varování v záznamech událostí od %s","%n varování v záznamech událostí od %s","%n varování v záznamech událostí od %s","%n varování v záznamech událostí od %s"],
    "Log Reader" : "Čtečka záznamů událostí (log)",
    "A log reader for Nextcloud" : "Čtečka záznamů událostí (log) pro Nextcloud",
    "Log reader for Nextcloud" : "Čtečka záznamů událostí pro Nextcloud",
    "Log reader" : "Čtečka záznamů událostí",
    "Open log reader settings" : "Otevřít nastavení pro čtečku záznamu událostí",
    "Log reader settings" : "Nastavení pro čtečku záznamů událostí",
    "Currently the log file {file} is shown" : "V tuto chvíli je zobrazován obsah souboru se záznamem událostí {file}",
    "Show server log" : "Zobrazit záznam událostí na serveru",
    "Live view is disabled" : "Živé zobrazení je vypnuté",
    "No log file" : "Žádný soubor se záznamem událostí",
    "File-based logging must be enabled to access logs from the Web UI." : "Aby bylo možné přistupovat k záznamům událostí z webového rozhraní, je třeba, aby bylo zapnuté jejich zaznamenávání do souborů.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Pokud se domníváte, že je to chyba, ověřte {setting} v {config} a nahlédněte do příručky pro správu Nextcloud.",
    "Level" : "Stupeň podrobnosti/závažnosti",
    "App" : "Aplikace",
    "No app in context" : "V kontextu není žádná aplikace",
    "Time" : "Čas",
    "Copy raw entry" : "Zkopírovat položku bez zpracování",
    "Copy formatted entry" : "Zkopírovat položku včetně formátu",
    "Hide exception details" : "Skrýt podrobnosti výjimky",
    "View exception details" : "Zobrazit podrobnosti výjimky",
    "Raw log entry" : "Nezpracovaná položka záznamu událostí",
    "Log entry successfully copied" : "Položka záznamu událostí úspěšně zkopírována",
    "Search log entries" : "Vyhledat v položkách záznamu událostí",
    "Caused by {exception}" : "Způsobeno {exception}",
    "Line {line}" : "Řádek {line}",
    "Filter log levels" : "Filtrovat podle stupně závažnosti",
    "Set log level" : "Nastavit stupeň podrobností záznamu událostí",
    "Time format" : "Formát času",
    "Live view" : "Živé zobrazení",
    "Download/Upload logs" : "Stáhnout si / nahrát záznamy událostí",
    "Download logs" : "Stáhnout si záznamy událostí",
    "Show local log file" : "Zobrazit místní soubor se záznamem událostí",
    "Upload local log file to be displayed" : "Nahrajte místní soubor se záznamem událostí, který chcete zobrazit",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Nepodařilo se zpracovat soubor se záznamem událostí",
    "Raw data" : "Nezpracovaná data",
    "Local time" : "Místní čas",
    "UTC time" : "Univerzální (UTC) čas",
    "Relative" : "Relativní",
    "Time format used for displaying the timestamp" : "Formát času sloužící pro zobrazování časového razítka",
    "(Local log files only support the \"raw\" time format)" : "(Místní soubory se záznamy událostí podporují pouze formát času \"raw\")",
    "Could not change date time format." : "Nepodařilo se změnit formát data a času.",
    "Polling is disabled because server is not configured to log to file" : "Dotazování je vypnuto protože server není nastaven tak, aby zaznamenával do souboru",
    "Polling (live view)" : "Dotazování (živé zobrazení)",
    "Could not change live view setting." : "Nepodařilo se změnit nastavení pro živé zobrazení.",
    "Filter logging levels" : "Filtrovat stupně naléhavostí záznamů",
    "Could not set logging levels to show" : "Nepodařilo se nastavit stupně naléhavostí pro zobrazení",
    "Set backend loglevel" : "Nastavit stupeň podrobností záznamu událostí v podpůrné vrstvě",
    "Could not set logging level" : "Nepodařilo se nastavit stupeň podrobností záznamu událostí",
    "Application" : "Aplikace",
    "Message" : "Zpráva",
    "Log entry actions" : "Akce ohledně položky záznamu událostí",
    "Loading older log entries" : "Načítání starčích položek záznamu událostí",
    "No older log entries available" : "Nejsou k dispozici žádné položky záznamu událostí",
    "Collapse row" : "Sbalit řádek",
    "Expand row" : "Rozbalit řádek",
    "Show details" : "Zobrazit podrobnosti",
    "Debug" : "Ladící",
    "Info" : "Informace",
    "Warning" : "Varování",
    "Error" : "Chyba",
    "Fatal" : "Fatální",
    "Could not load log entries" : "Nepodařilo se načíst položky záznamu událostí",
    "Clipboard" : "Schránka",
    "Could not parse clipboard content" : "Nelze parsovat obsah schránky",
    "Could not fetch new log entries (server unavailable)" : "Nepodařilo se získat nové položky záznamu událostí (server není k dispozici)",
    "Could not fetch new entries" : "Nepodařilo se získat nové položky",
    "Could not copy to clipboard, please copy manually:" : "Nepodařilo se zkopírovat do schránky – zkopírujte ručně:",
    "\tfrom {address} by {user} at {time}\n" : "\tz {address} od {user} v {time}\n",
    "line {line}" : "řádek {line}",
    "Download / Upload logs" : "Stáhnout si / nahrát záznamy událostí"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-29.0.12.tgz: nextcloud/apps/logreader/l10n/cs.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Záznam událostí",
    "Errors in the log" : "Chyby v záznamu událostí",
    "Failed to get an iterator for log entries: %s" : "Nepodařilo se získat iterátor pro položky záznamu událostí: %s",
    "No errors in the logs since %s" : "Žádné chyby v záznamech událostí od %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n chyba v záznamech událostí od %s","%n chyby v záznamech událostí od %s","%n chyb v záznamech událostí od %s","%n chyby v záznamech událostí od %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n varování v záznamech událostí od %s","%n varování v záznamech událostí od %s","%n varování v záznamech událostí od %s","%n varování v záznamech událostí od %s"],
    "Log Reader" : "Čtečka záznamů událostí (log)",
    "A log reader for Nextcloud" : "Čtečka záznamů událostí (log) pro Nextcloud",
    "Log reader for Nextcloud" : "Čtečka záznamů událostí pro Nextcloud",
    "Log reader" : "Čtečka záznamů událostí",
    "Open log reader settings" : "Otevřít nastavení pro čtečku záznamu událostí",
    "Log reader settings" : "Nastavení pro čtečku záznamů událostí",
    "Currently the log file {file} is shown" : "V tuto chvíli je zobrazován obsah souboru se záznamem událostí {file}",
    "Show server log" : "Zobrazit záznam událostí na serveru",
    "Live view is disabled" : "Živé zobrazení je vypnuté",
    "No log file" : "Žádný soubor se záznamem událostí",
    "File-based logging must be enabled to access logs from the Web UI." : "Aby bylo možné přistupovat k záznamům událostí z webového rozhraní, je třeba, aby bylo zapnuté jejich zaznamenávání do souborů.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Pokud se domníváte, že je to chyba, ověřte {setting} v {config} a nahlédněte do příručky pro správu Nextcloud.",
    "Level" : "Stupeň podrobnosti/závažnosti",
    "App" : "Aplikace",
    "No app in context" : "V kontextu není žádná aplikace",
    "Time" : "Čas",
    "Copy raw entry" : "Zkopírovat položku bez zpracování",
    "Copy formatted entry" : "Zkopírovat položku včetně formátu",
    "Hide exception details" : "Skrýt podrobnosti výjimky",
    "View exception details" : "Zobrazit podrobnosti výjimky",
    "Raw log entry" : "Nezpracovaná položka záznamu událostí",
    "Log entry successfully copied" : "Položka záznamu událostí úspěšně zkopírována",
    "Search log entries" : "Vyhledat v položkách záznamu událostí",
    "Caused by {exception}" : "Způsobeno {exception}",
    "Line {line}" : "Řádek {line}",
    "Filter log levels" : "Filtrovat podle stupně závažnosti",
    "Set log level" : "Nastavit stupeň podrobností záznamu událostí",
    "Time format" : "Formát času",
    "Live view" : "Živé zobrazení",
    "Download/Upload logs" : "Stáhnout si / nahrát záznamy událostí",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Položky ze záznamu událostí, které jste si zkopírovali do schránky, je možné si také zobrazit jejich vložením do zobrazení záznamu událostí pomocí: {keyboardShortcut}",
    "Download logs" : "Stáhnout si záznamy událostí",
    "Show local log file" : "Zobrazit místní soubor se záznamem událostí",
    "Upload local log file to be displayed" : "Nahrajte místní soubor se záznamem událostí, který chcete zobrazit",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Nepodařilo se zpracovat soubor se záznamem událostí",
    "Raw data" : "Nezpracovaná data",
    "Local time" : "Místní čas",
    "UTC time" : "Univerzální (UTC) čas",
    "Relative" : "Relativní",
    "Time format used for displaying the timestamp" : "Formát času sloužící pro zobrazování časového razítka",
    "(Local log files only support the \"raw\" time format)" : "(Místní soubory se záznamy událostí podporují pouze formát času \"raw\")",
    "Could not change date time format." : "Nepodařilo se změnit formát data a času.",
    "Polling is disabled because server is not configured to log to file" : "Dotazování je vypnuto protože server není nastaven tak, aby zaznamenával do souboru",
    "Polling (live view)" : "Dotazování (živé zobrazení)",
    "Could not change live view setting." : "Nepodařilo se změnit nastavení pro živé zobrazení.",
    "Filter logging levels" : "Filtrovat stupně naléhavostí záznamů",
    "Could not set logging levels to show" : "Nepodařilo se nastavit stupně naléhavostí pro zobrazení",
    "Set backend loglevel" : "Nastavit stupeň podrobností záznamu událostí v podpůrné vrstvě",
    "Could not set logging level" : "Nepodařilo se nastavit stupeň podrobností záznamu událostí",
    "Application" : "Aplikace",
    "Message" : "Zpráva",
    "Log entry actions" : "Akce ohledně položky záznamu událostí",
    "Loading older log entries" : "Načítání starších položek záznamu událostí",
    "No older log entries available" : "Nejsou k dispozici žádné položky záznamu událostí",
    "Collapse row" : "Sbalit řádek",
    "Expand row" : "Rozbalit řádek",
    "Show details" : "Zobrazit podrobnosti",
    "Debug" : "Ladící",
    "Info" : "Informace",
    "Warning" : "Varování",
    "Error" : "Chyba",
    "Fatal" : "Fatální",
    "Could not load log entries" : "Nepodařilo se načíst položky záznamu událostí",
    "Clipboard" : "Schránka",
    "Could not parse clipboard content" : "Nepodařilo se zpracovat obsah schránky",
    "Could not fetch new log entries (server unavailable)" : "Nepodařilo se získat nové položky záznamu událostí (server není k dispozici)",
    "Could not fetch new entries" : "Nepodařilo se získat nové položky",
    "Could not copy to clipboard, please copy manually:" : "Nepodařilo se zkopírovat do schránky – zkopírujte ručně:",
    "\tfrom {address} by {user} at {time}\n" : "\tz {address} od {user} v {time}\n"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
